@@ -27,7 +27,10 @@ class BlockManager:
 		if name in BLOCKS.keys() :
 			block = BLOCKS[name]
 		else :
-			LOGGER.log(logging.DEBUG, "Could not find block with name : %s " % name)
+			message = "Could not find block with name : %s" % name
+			if len(BLOCKS) > 0 :
+				message = "%s \n Valid Block names are : %s" % (message, ",".join([ name for name,data in BLOCKS.items() ]))
+			LOGGER.log(logging.DEBUG, message)
 			block = None
 		return block
 
